==> portal-transparencia-1.121.0.zip: BOOT-INF/classes/db/sql/contab/subvencao-prestacao-contas.sql <==
SELECT S.ENTIDADE,
       S.EXERCICIO,
       S.SUBVENCAO,
       S.ANOSUBVENCAO,
       S.SEQUENCIA,
       S.DATA,
       T.DESCRICAO AS TIPO,
       S.DESCRICAO,
       S.DATAPRAZO,
       CASE SS.PERIODICIDADEPRESTACAO 
            WHEN '1' THEN 
            CASE S.PERIODOPRESTACAO 
                 WHEN '1' THEN 'Janeiro'
                 WHEN '2' THEN 'Fevereiro'
                 WHEN '3' THEN 'Março'
                 WHEN '4' THEN 'Abril'
                 WHEN '5' THEN 'Maio'
                 WHEN '6' THEN 'Junho'
                 WHEN '7' THEN 'Julho'
                 WHEN '8' THEN 'Agosto'
                 WHEN '9' THEN 'Setembro'
                 WHEN '10' THEN 'Outubro'
                 WHEN '11' THEN 'Novembro'
                 WHEN '12' THEN 'Dezembro'
            END
            WHEN '2' THEN S.PERIODOPRESTACAO 
            WHEN '3' THEN S.PERIODOPRESTACAO 
            WHEN '4' THEN 
            CASE S.PERIODOPRESTACAO 
                 WHEN '1' THEN '1º Bimestre'
                 WHEN '2' THEN '2º Bimestre'
                 WHEN '3' THEN '3º Bimestre'
                 WHEN '4' THEN '4º Bimestre'
            END
       END PERIODOPRESTACAO,
       S.DATAPREVISTA
  FROM SUBVENCAOSOCIAL SS
  JOIN SUBVENCAOSITUACAO S
    ON S.ENTIDADE     = SS.ENTIDADE
   AND S.EXERCICIO    = SS.EXERCICIO
   AND S.SUBVENCAO    = SS.SUBVENCAO
   AND S.ANOSUBVENCAO = SS.ANOSUBVENCAO
  JOIN TIPOSITUACAOSUBVENCAO T
    ON T.ID = S.IDTIPOSITUACAO
 WHERE SS.ENTIDADE     = :entidade
   AND SS.EXERCICIO    = :exercicio
   AND SS.SUBVENCAO    = :subvencao
   AND SS.ANOSUBVENCAO = :anoSubvencao

==> portal-transparencia-2.106.0.zip: BOOT-INF/classes/db/sql/contab/subvencao-prestacao-contas.sql <==
SELECT S.ENTIDADE,
       S.EXERCICIO,
       S.SUBVENCAO,
       S.ANOSUBVENCAO,
       S.SEQUENCIA,
       S.DATA,
       T.DESCRICAO AS TIPO,
       S.DESCRICAO,
       S.DATAPRAZO,
       CASE SS.PERIODICIDADEPRESTACAO 
            WHEN '1' THEN 
            CASE S.PERIODOPRESTACAO 
                 WHEN '1' THEN 'Janeiro'
                 WHEN '2' THEN 'Fevereiro'
                 WHEN '3' THEN 'Março'
                 WHEN '4' THEN 'Abril'
                 WHEN '5' THEN 'Maio'
                 WHEN '6' THEN 'Junho'
                 WHEN '7' THEN 'Julho'
                 WHEN '8' THEN 'Agosto'
                 WHEN '9' THEN 'Setembro'
                 WHEN '10' THEN 'Outubro'
                 WHEN '11' THEN 'Novembro'
                 WHEN '12' THEN 'Dezembro'
            END
            WHEN '2' THEN S.PERIODOPRESTACAO 
            WHEN '3' THEN S.PERIODOPRESTACAO 
            WHEN '4' THEN 
            CASE S.PERIODOPRESTACAO 
                 WHEN '1' THEN '1º Bimestre'
                 WHEN '2' THEN '2º Bimestre'
                 WHEN '3' THEN '3º Bimestre'
                 WHEN '4' THEN '4º Bimestre'
            END
       END PERIODOPRESTACAO,
       S.DATAPREVISTA
  FROM ${db.contabilidade.schema}.SUBVENCAOSOCIAL SS
  JOIN ${db.contabilidade.schema}.SUBVENCAOSITUACAO S
    ON S.ENTIDADE     = SS.ENTIDADE
   AND S.EXERCICIO    = SS.EXERCICIO
   AND S.SUBVENCAO    = SS.SUBVENCAO
   AND S.ANOSUBVENCAO = SS.ANOSUBVENCAO
  JOIN ${db.contabilidade.schema}.TIPOSITUACAOSUBVENCAO T
    ON T.ID = S.IDTIPOSITUACAO
 WHERE SS.ENTIDADE     = :entidade
   AND SS.EXERCICIO    = :exercicio
   AND SS.SUBVENCAO    = :subvencao
   AND SS.ANOSUBVENCAO = :anoSubvencao
